@@ -1,8 +1,7 @@
 import subprocess
 import shutil
-import os
-from everviz.util import get_everviz_folder, DEFAULT_CONFIG
-from everviz.config import write_webviz_config, webviz_config
+from everviz.util import get_everviz_folder
+from everviz.config import setup_default_everviz_config
 from everviz.log import setup_logger
 
 
@@ -20,18 +19,12 @@ except ImportError:
 
 @hookimpl
 def visualize_data(api):
-    file_name = DEFAULT_CONFIG
     everviz_folder = get_everviz_folder(api)
     logger = setup_logger(everviz_folder)
 
-    config = webviz_config(api)
-    config_file_path = os.path.join(everviz_folder, file_name)
-    write_webviz_config(config, config_file_path)
-
-    # The entry point of webviz is to call it from command line, and so we do.
+    config_path = setup_default_everviz_config(api)
+    # The entry point of webviz is to call it from command line, and so do we.
     if shutil.which("webviz"):
-        subprocess.call(
-            ["webviz", "build", file_name, "--theme", "equinor"], cwd=everviz_folder
-        )
+        subprocess.call(["webviz", "build", config_path, "--theme", "equinor"])
     else:
         logger.error("Failed to find webviz")
