@@ -4,22 +4,17 @@ import pandas
 import numpy
 
 
-def calculate_statistics(summary_values):
-    # Find the key names.
-    value_vars = [
-        column
-        for column in summary_values.columns
-        if column not in ["batch", "date", "realization"]
-    ]
-
+def calculate_statistics(summary_values, keys):
+    if keys is None or len(keys) == 0:
+        raise AssertionError("List of summary keys is required")
     # Make rows out of the keys for statistics.
     reshaped_summary_values = pandas.melt(
         summary_values,
         id_vars=["batch", "date", "realization"],
-        value_vars=value_vars,
+        value_vars=keys,
         var_name="summary_key",
         value_name="value",
-    )
+    ).dropna()
 
     # Aggregate the values over the realizations, using pivot_table, keeping the
     # key, batch and date as the multi-index, calculating statistics of the
